Manipulating Schemas
--------------------

The SchemaView class in the linkml-runtime provides a method for
dynamically introspecting and manipulating schemas, for example:

* find all ancestors or descendants of a class
* find all inferred (induced) slots for a class

See `runtime notebooks
<https://github.com/linkml/linkml-runtime/tree/main/notebooks>`_ for an example


.. currentmodule:: linkml_runtime.utils.schemaview
                   
.. autoclass:: SchemaView
    :members:                
    :inherited-members:
